[![Codacy Badge](https://api.codacy.com/project/badge/Grade/5b24d3105ea34ab1a4414c8f0c31e51d)](https://www.codacy.com/app/Kaiz0r/AppImages-Manager?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=Kaiz0r/AppImages-Manager&amp;utm_campaign=Badge_Grade)
[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)
[![Discord](https://img.shields.io/discord/396716931962503169.svg?style=popout)](http://discord.gg/KUA8acb)

# AppImages-Manager
A little project i made for myself to sort my AppImages collection.
I made it really just for myself to be able to sort and categorize my AppImages in an automated method, but I thought i'd share it incase anyone else finds it useful.

Open the Config button in the app to choose where your Downloads folder is (where your browser will download appimages to), and the Storage path (Where this app stores the appimages).
Press Install button to move all apps from Downloads in to Storage.
Refresh reloads the list box with the files that are in Storage.
Run launches the selected app. If the app doesn't have permissions to execute, it'll handle that automatically.
Delete removes the selected appimage file from the system.
Group button allows you to sort the selected image in to categories or groups. Either enter a name in the box for a new group, or select a button for an existing group.
Edit button lets you edit the groups. (For now, just used for removing images from a group.

# CLI Version
There is also a command-line version available. Run the aim-cli.py script for a non-gui way of quickly managing appimages.
If run on its own, enters an interactive mode where it'll ask for commands as you go. If you run it with command arguments, it'll run the command then exit.
aim-cli.py help shows all the commands
Currently supported operations: finding apps in directory, running apps, installing apps from Downloads, automatically handling execution permissions on appimages.

# Requires
Just tkinter. Everything else should be stock python3 libraries.
Only tested in python3.
